# CMeel zlib

[![PyPI version](https://badge.fury.io/py/cmeel-zlib.svg)](https://pypi.org/project/cmeel-zlib)
[![Release](https://github.com/cmake-wheel/cmeel-zlib/actions/workflows/release.yml/badge.svg)](https://github.com/cmake-wheel/cmeel-zlib/actions/workflows/release.yml)

[zlib](https://zlib.net/) distribution for cmeel packages.
